diff -pruN 5.69.0-1/autotests/test_autodetect.cpp 5.70.0-0ubuntu1/autotests/test_autodetect.cpp
--- 5.69.0-1/autotests/test_autodetect.cpp	2020-04-04 23:07:54.000000000 +0000
+++ 5.70.0-0ubuntu1/autotests/test_autodetect.cpp	2020-05-02 22:25:43.000000000 +0000
@@ -16,33 +16,50 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
+#include "guesslanguage.h"
+#include "speller.h"
 
 #include <QObject>
 #include <qtest.h>
-#include "guesslanguage.h"
+#include <QStandardPaths>
 
 class SonnetAutoDetectTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
-   
+    void initTestCase();
     void autodetect_data();
     void autodetect();
 };
 
+using namespace Sonnet;
+
+void SonnetAutoDetectTest::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+
+    Speller speller(QStringLiteral("en_US"));
+
+    if (speller.availableBackends().empty()) {
+        QSKIP("No backends available");
+    }
+
+    if (!speller.availableBackends().contains(QLatin1String("Hunspell"))) {
+        QSKIP("Hunspell not available");
+    }
+
+    speller.setDefaultClient(QStringLiteral("Hunspell"));
+    speller.setAttribute(Speller::AutoDetectLanguage, true);
+}
+
 void SonnetAutoDetectTest::autodetect_data()
 {
     QTest::addColumn<QString>("sentence");
     QTest::addColumn<QString>("correct_lang");
     QTest::addColumn<QStringList>("suggested_langs");
-    
-    /* These tests will fail if you dont have the respective dictionary installed.
-     * They will also fail if the dictionary file name is different from 'correct_lang'
-     */
-    QTest::newRow("English") << QStringLiteral("This is an English sentence.") << QStringLiteral("en_US-large") << QStringList{QLatin1String("en_US-large"), QLatin1String("de_DE"), QLatin1String("ur_PK")};
-    
-    QTest::newRow("German") << QStringLiteral("Dies ist ein deutscher Satz.") << QStringLiteral("de_DE_frami") << QStringList{QLatin1String("hi_IN"), QLatin1String("pl_PL"), QLatin1String("de_DE_frami")};
-    
+
+    QTest::newRow("English") << QStringLiteral("This is an English sentence.") << QStringLiteral("en_US") << QStringList{QLatin1String("en_US"), QLatin1String("de_DE"), QLatin1String("ur_PK")};
+    QTest::newRow("German") << QStringLiteral("Dies ist ein deutscher Satz.") << QStringLiteral("de_DE") << QStringList{QLatin1String("hi_IN"), QLatin1String("pl_PL"), QLatin1String("de_DE_frami")};
     QTest::newRow("Malayam") << QStringLiteral("ഇന്ത്യയുടെ തെക്കു ഭാഗത്തു സ്ഥിതി ചെയ്യുന്ന ഒരു സംസ്ഥാനമാണ് കേരളം.") << QStringLiteral("ml_IN") << QStringList{QLatin1String("ml_IN"), QLatin1String("ur_PK"), QLatin1String("en_US-large")};
 }
 
@@ -51,11 +68,28 @@ void SonnetAutoDetectTest::autodetect()
     QFETCH(QString, sentence);
     QFETCH(QString, correct_lang);
     QFETCH(QStringList, suggested_langs);
- 
+
+    //skip if the language is not available
+    Speller speller;
+    if (!speller.availableLanguages().contains(correct_lang)) {
+        const QString msg = correct_lang + QStringLiteral(" not available");
+        QSKIP(msg.toLocal8Bit().constData());
+    }
+
     Sonnet::GuessLanguage gl;
     QString actual_lang = gl.identify(sentence, suggested_langs);
-    
-    QCOMPARE(actual_lang, correct_lang);
+
+    //get chars till _, get the language code
+    int us = correct_lang.indexOf(QLatin1Char('_'));
+    const QStringRef correctLangCode = correct_lang.leftRef(us);
+
+    us = actual_lang.indexOf(QLatin1Char('_'));
+    const QStringRef actualLangCode = actual_lang.leftRef(us);
+
+    qDebug() << "Actual: " << actual_lang;
+    qDebug() << "Expected: " << correct_lang;
+
+    QCOMPARE(actualLangCode, correctLangCode);
 }
 
 QTEST_GUILESS_MAIN(SonnetAutoDetectTest)
diff -pruN 5.69.0-1/CMakeLists.txt 5.70.0-0ubuntu1/CMakeLists.txt
--- 5.69.0-1/CMakeLists.txt	2020-04-04 23:07:54.000000000 +0000
+++ 5.70.0-0ubuntu1/CMakeLists.txt	2020-05-02 22:25:43.000000000 +0000
@@ -1,10 +1,10 @@
 cmake_minimum_required(VERSION 3.5)
 
-set(KF5_VERSION "5.69.0") # handled by release scripts
+set(KF5_VERSION "5.70.0") # handled by release scripts
 project(Sonnet VERSION ${KF5_VERSION})
 
 include(FeatureSummary)
-find_package(ECM 5.69.0  NO_MODULE)
+find_package(ECM 5.70.0  NO_MODULE)
 set_package_properties(ECM PROPERTIES TYPE REQUIRED DESCRIPTION "Extra CMake Modules." URL "https://commits.kde.org/extra-cmake-modules")
 feature_summary(WHAT REQUIRED_PACKAGES_NOT_FOUND FATAL_ON_MISSING_REQUIRED_PACKAGES)
 
diff -pruN 5.69.0-1/debian/changelog 5.70.0-0ubuntu1/debian/changelog
--- 5.69.0-1/debian/changelog	2020-04-29 22:56:14.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/changelog	2020-05-09 11:35:42.000000000 +0000
@@ -1,94 +1,156 @@
-sonnet (5.69.0-1) experimental; urgency=medium
+sonnet (5.70.0-0ubuntu1) groovy; urgency=medium
 
-  * Team upload.
+  [ José Manuel Santamaría Lema ]
+  * New upstream release (5.69.0)
+  * Update symbols files
 
-  [ Sandro Knauß ]
-  * Bump compat level to 12.
-  * Bump Standards-Version to 4.5.0 (No changes needed).
-  * Get rid of debug-symbol-migration package.
-  * Add Rules-Requires-Root field to control.
-  * New upstream release (5.69.0).
-  * Update build-deps and deps with the info from cmake.
-  * Enable hardening all.
-  * Add Build-Depends-Package to symbols files.
-  * Remove missing file trigrams.map from sonnet-plugins.install.
-  * Update symbols from build for 5.69.0.
-  * Use secure uri for watch file.
-  * Remove duplicate section field for libkf5sonnetcore5.
-  * Remove not needed injection of linker flags.
+  [ Rik Mills ]
+  * New upstream release (5.70.0)
 
- -- Sandro Knauß <hefee@debian.org>  Thu, 30 Apr 2020 00:56:14 +0200
+ -- Rik Mills <rikmills@kde.org>  Sat, 09 May 2020 12:35:42 +0100
 
-sonnet (5.62.0-1) unstable; urgency=medium
+sonnet (5.68.0-0ubuntu1) focal; urgency=medium
 
-  * Update reprotest args variable
-  * New upstream release (5.62.0).
-  * Update build-deps and deps with the info from cmake
-  * Release to unstable
+  * New upstream release (5.68.0)
 
- -- Maximiliano Curia <maxy@debian.org>  Fri, 20 Sep 2019 10:13:19 -0700
+ -- Rik Mills <rikmills@kde.org>  Wed, 25 Mar 2020 21:01:10 +0000
 
-sonnet (5.61.0-1) experimental; urgency=medium
+sonnet (5.67.0-0ubuntu1) focal; urgency=medium
 
-  [ Maximiliano Curia ]
-  * Salsa CI automatic initialization by Tuco
-  * New upstream release (5.61.0).
-  * Update symbols files.
-  * Ignore reprotest build path variations
-  * Update build-deps and deps with the info from cmake
-  * Add missing version to maintscript
-  * Release to experimental
+  * New upstream release (5.67.0)
 
-  [ Jonathan Riddell ]
-  * moved qdebug files
+ -- Rik Mills <rikmills@kde.org>  Sat, 08 Feb 2020 09:53:55 +0000
 
- -- Maximiliano Curia <maxy@debian.org>  Mon, 09 Sep 2019 21:11:14 +0100
+sonnet (5.66.0-0ubuntu1) focal; urgency=medium
 
-sonnet (5.54.0-1) unstable; urgency=medium
+  * New upstream release (5.66.0)
 
-  * New upstream release (5.52.0).
-  * Update build-deps and deps with the info from cmake
-  * New upstream release (5.53.0).
-  * Update build-deps and deps with the info from cmake
-  * New upstream release (5.54.0).
-  * Update build-deps and deps with the info from cmake
-  * Update symbols files.
-  * Bump group breaks (5.54)
-  * Release to unstable
+ -- Rik Mills <rikmills@kde.org>  Sat, 11 Jan 2020 13:22:52 +0000
 
- -- Maximiliano Curia <maxy@debian.org>  Thu, 17 Jan 2019 19:27:42 -0300
+sonnet (5.65.0-0ubuntu1) focal; urgency=medium
 
-sonnet (5.51.0-1) unstable; urgency=medium
+  * New upstream release (5.65.0)
+  * Update symbols
 
-  * New upstream release (5.50.0).
-  * Update build-deps and deps with the info from cmake
-  * Bump group breaks (5.50)
-  * New upstream release (5.51.0).
-  * Update build-deps and deps with the info from cmake
-  * Bump group breaks (5.51)
-  * Release to unstable
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Sat, 14 Dec 2019 23:03:45 +0000
 
- -- Maximiliano Curia <maxy@debian.org>  Wed, 07 Nov 2018 17:17:40 +0100
+sonnet (5.64.0-0ubuntu1) focal; urgency=medium
 
-sonnet (5.49.0-1) unstable; urgency=medium
+  * New upstream release (5.63.0)
+  * New upstream release (5.64.0)
+  * Update install files.
 
-  * New upstream release (5.48.0).
-  * Update build-deps and deps with the info from cmake
-  * New upstream release (5.49.0).
-  * Update build-deps and deps with the info from cmake
-  * Bump group breaks (5.49)
-  * Release to unstable
+ -- Rik Mills <rikmills@kde.org>  Sat, 09 Nov 2019 21:27:58 +0000
 
- -- Maximiliano Curia <maxy@debian.org>  Fri, 17 Aug 2018 16:19:20 +0200
+sonnet (5.62.0-0ubuntu1) eoan; urgency=medium
 
-sonnet (5.47.0-1) unstable; urgency=medium
+  * Install designer plugin in -dev package.
+  * New upstream release (5.62.0)
 
-  * New upstream release (5.47.0).
-  * Update build-deps and deps with the info from cmake
-  * Bump group breaks (5.47)
-  * Release to unstable
+ -- Rik Mills <rikmills@kubuntu.org>  Sat, 14 Sep 2019 08:10:27 +0100
+
+sonnet (5.61.0-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (5.61.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Mon, 12 Aug 2019 10:46:09 +0100
+
+sonnet (5.60.0-0ubuntu1) eoan; urgency=medium
+
+  * Move qdebug categories file to new location.
+  * New upstream release (5.60.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sat, 20 Jul 2019 08:19:29 +0100
+
+sonnet (5.59.0-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (5.59.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Wed, 12 Jun 2019 11:22:40 +0100
+
+sonnet (5.58.0-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (5.58.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Mon, 13 May 2019 15:43:54 +0100
+
+sonnet (5.57.0-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (5.57.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Mon, 22 Apr 2019 08:41:24 +0100
 
- -- Maximiliano Curia <maxy@debian.org>  Fri, 15 Jun 2018 12:11:14 +0200
+sonnet (5.56.0-0ubuntu1) disco; urgency=medium
+
+  [ José Manuel Santamaría Lema ]
+  * New upstream release (5.56.0)
+
+  [ Rik Mills ]
+  * Update symbols from build logs.
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Sat, 09 Mar 2019 16:39:06 +0000
+
+sonnet (5.55.0-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (5.55.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Wed, 13 Feb 2019 08:34:34 +0000
+
+sonnet (5.54.0-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (5.54.0)
+  * Update symbols from build logs.
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sun, 13 Jan 2019 12:37:39 +0000
+
+sonnet (5.53.0-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (5.53.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Sun, 09 Dec 2018 20:51:12 +0000
+
+sonnet (5.52.0-0ubuntu2) disco; urgency=medium
+
+  * No-change rebuild against latest hunspell
+
+ -- Jeremy Bicha <jbicha@ubuntu.com>  Thu, 29 Nov 2018 06:02:30 -0500
+
+sonnet (5.52.0-0ubuntu1) disco; urgency=medium
+
+  [ Rik Mills ]
+  * New upstream release (5.51.0)
+
+  [ José Manuel Santamaría Lema ]
+  * New upstream release (5.52.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Thu, 22 Nov 2018 14:44:34 +0000
+
+sonnet (5.50.0-0ubuntu1) cosmic; urgency=medium
+
+  * New upstream release (5.50.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Mon, 10 Sep 2018 22:20:18 +0100
+
+sonnet (5.49.0-0ubuntu1) cosmic; urgency=medium
+
+  [ Rik Mills ]
+  * New upstream release (5.48.0)
+  * New upstream release (5.49.0)
+
+  [ José Manuel Santamaría Lema ]
+  * Move away from dhmk and set compat level to 11 in order to reduce
+    delta with Debian
+
+ -- Rik Mills <rikmills@kubuntu.org>  Tue, 21 Aug 2018 20:32:40 +0100
+
+sonnet (5.47.0-0ubuntu1) cosmic; urgency=medium
+
+  * New upstream release (5.47.0)
+  * Merge with debian, notes:
+    - keep using dhmk and debhelper compat level = 9, see:
+      https://phabricator.kde.org/w/kubuntu/black-operations/pyramid/
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 14 Jun 2018 15:52:05 +0100
 
 sonnet (5.46.0-1) unstable; urgency=medium
 
@@ -102,6 +164,14 @@ sonnet (5.46.0-1) unstable; urgency=medi
 
  -- Maximiliano Curia <maxy@debian.org>  Thu, 17 May 2018 22:15:58 +0200
 
+sonnet (5.46.0-0ubuntu1) cosmic; urgency=medium
+
+  * New upstream release (5.45.0)
+  * New upstream release (5.46.0)
+  * Update symbols from build logs
+
+ -- Rik Mills <rikmills@kubuntu.org>  Tue, 15 May 2018 15:59:09 +0100
+
 sonnet (5.45.0-1) unstable; urgency=medium
 
   * New upstream release (5.45.0).
@@ -120,6 +190,12 @@ sonnet (5.44.0-1) sid; urgency=medium
 
  -- Maximiliano Curia <maxy@debian.org>  Wed, 21 Mar 2018 14:41:36 +0100
 
+sonnet (5.44.0-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (5.44.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Mon, 12 Mar 2018 20:00:42 +0000
+
 sonnet (5.43.0-1) experimental; urgency=medium
 
   * Use the salsa canonical urls
@@ -130,6 +206,12 @@ sonnet (5.43.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Mon, 26 Feb 2018 11:44:27 +0100
 
+sonnet (5.43.0-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (5.43.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sun, 11 Feb 2018 11:18:05 +0000
+
 sonnet (5.42.0-2) sid; urgency=medium
 
   * New revision
@@ -152,6 +234,13 @@ sonnet (5.42.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Fri, 02 Feb 2018 12:06:20 +0100
 
+sonnet (5.42.0-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (5.42.0)
+  * Update symbols from build logs
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 26 Jan 2018 22:24:34 +0000
+
 sonnet (5.41.0-1) experimental; urgency=medium
 
   * New upstream release (5.41.0).
@@ -163,12 +252,26 @@ sonnet (5.41.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Fri, 15 Dec 2017 10:43:28 -0300
 
+sonnet (5.41.0-0ubuntu1) bionic; urgency=low
+
+  * New upstream release (5.41.0)
+
+ -- Walter Lapchynski <wxl@ubuntu.com>  Sun, 10 Dec 2017 22:10:13 -0600
+
 sonnet (5.41.0-0neon) xenial; urgency=medium
 
   * New release
 
  -- Neon CI <neon@kde.org>  Fri, 08 Dec 2017 14:49:17 +0000
 
+sonnet (5.40.0-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (5.39.0)
+  * New upstream release (5.40.0)
+  * Update symbols from build logs
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 24 Nov 2017 17:19:08 +0000
+
 sonnet (5.40.0-0neon) xenial; urgency=medium
 
   * New release
@@ -181,6 +284,14 @@ sonnet (5.39.0-0neon) xenial; urgency=me
 
  -- Neon CI <neon@kde.org>  Sun, 15 Oct 2017 11:48:01 +0000
 
+sonnet (5.38.0-0ubuntu1) artful; urgency=medium
+
+  * Update sybmols from build logs. Remove private symbols now upstream
+    changes ensure these are no longer leaked
+  * New upstream release (5.38.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Mon, 11 Sep 2017 13:18:31 +0100
+
 sonnet (5.37.0-2) sid; urgency=medium
 
   * New revision
@@ -202,6 +313,12 @@ sonnet (5.37.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Wed, 16 Aug 2017 10:42:35 +0200
 
+sonnet (5.37.0-0ubuntu1) artful; urgency=low
+
+  * New upstream release (5.37.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sat, 12 Aug 2017 18:47:45 +0100
+
 sonnet (5.36.0-1) experimental; urgency=medium
 
   [ Maximiliano Curia ]
@@ -228,6 +345,64 @@ sonnet (5.36.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Sun, 09 Jul 2017 23:41:36 +0200
 
+sonnet (5.36.0-0ubuntu3) artful; urgency=medium
+
+  * Revert last change. Build with hunspell again
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 20 Jul 2017 13:02:02 +0100
+
+sonnet (5.36.0-0ubuntu2) artful; urgency=medium
+
+  * Temporarily do not build against hunspell to avoid brokenness of a
+    partial frameworks migration. Will immediately be re-enabled in a
+    follow up upload, that can wait in -proposed with hunspell.
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 20 Jul 2017 07:45:19 +0100
+
+sonnet (5.36.0-0ubuntu1) artful; urgency=low
+
+  * New upstream release (5.36.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Tue, 11 Jul 2017 23:52:40 +0100
+
+sonnet (5.35.0-0ubuntu2) artful; urgency=medium
+
+  * No-change rebuild against latest hunspell
+
+ -- Jeremy Bicha <jbicha@ubuntu.com>  Tue, 20 Jun 2017 05:41:01 -0400
+
+sonnet (5.35.0-0ubuntu1) artful; urgency=low
+
+  * New upstream release (5.35.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Mon, 12 Jun 2017 22:57:39 +0100
+
+sonnet (5.34.0-0ubuntu1) artful; urgency=low
+
+  * New upstream release (5.34.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Mon, 15 May 2017 21:25:35 +0100
+
+sonnet (5.33.0-0ubuntu1) artful; urgency=low
+
+  * New upstream release (5.33.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Sat, 29 Apr 2017 18:04:45 +0100
+
+sonnet (5.31.0-0ubuntu1) zesty; urgency=medium
+
+  * Pass '-fno-keep-inline-functions' to gcc in the acc test in order to
+    avoid possible spurious test failures.
+  * New upstream release (5.31.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Tue, 14 Feb 2017 22:50:45 +0000
+
+sonnet (5.30.0-0ubuntu1) zesty; urgency=low
+
+  * New upstream release (5.30.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Wed, 01 Feb 2017 18:34:26 +0000
+
 sonnet (5.28.0-2) unstable; urgency=medium
 
   * Update the sonnet-plugins package description (Closes: 801728)
@@ -249,6 +424,20 @@ sonnet (5.28.0-1) unstable; urgency=medi
 
  -- Maximiliano Curia <maxy@debian.org>  Fri, 18 Nov 2016 16:03:17 +0100
 
+sonnet (5.28.0-0ubuntu1) zesty; urgency=low
+
+  [ Rik Mills ]
+  * New upstream release (5.27.0)
+
+  [ José Manuel Santamaría Lema ]
+  * Update Vcs-Git field to use https:// instead of git://
+  * Merge with debian, importing the libkf5sonnet-dev-bin package, add
+    Breaks/Replaces against previous versions of libkf5sonnet-dev in
+    libkf5sonnet-dev-bin.
+  * New upstream release (5.28.0)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Mon, 05 Dec 2016 20:16:29 +0000
+
 sonnet (5.28.0-0neon) xenial; urgency=medium
 
   * New release
@@ -283,6 +472,13 @@ sonnet (5.26.0-1) unstable; urgency=medi
 
  -- Maximiliano Curia <maxy@debian.org>  Thu, 29 Sep 2016 11:58:31 +0200
 
+sonnet (5.26.0-0ubuntu1) yakkety; urgency=medium
+
+  * Adding usr/bin/gentrigrams to install file
+  * New upstream release (5.26.0)
+
+ -- Rik Mills <rik.mills88@gmail.com>  Thu, 22 Sep 2016 13:53:50 +0100
+
 sonnet (5.26.0-0neon) xenial; urgency=medium
 
   * New release
@@ -305,6 +501,12 @@ sonnet (5.25.0-0neon) xenial; urgency=me
 
  -- Neon CI <neon@kde.org>  Sat, 13 Aug 2016 20:17:05 +0000
 
+sonnet (5.24.0-0ubuntu1) yakkety; urgency=medium
+
+  * New upstream release (5.24.0)
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Tue, 26 Jul 2016 08:52:26 +0000
+
 sonnet (5.24.0-0neon) xenial; urgency=medium
 
   * New release
@@ -318,6 +520,12 @@ sonnet (5.23.0-1) unstable; urgency=medi
 
  -- Maximiliano Curia <maxy@debian.org>  Sat, 18 Jun 2016 08:32:31 +0200
 
+sonnet (5.23.0-0ubuntu1) yakkety; urgency=medium
+
+  * New upstream release (5.23.0)
+
+ -- Clive Johnston <clivejo@kubuntu.org>  Mon, 11 Jul 2016 22:25:33 +0200
+
 sonnet (5.23.0-0neon) xenial; urgency=medium
 
   * New release
@@ -340,6 +548,23 @@ sonnet (5.22.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Wed, 18 May 2016 23:42:06 +0200
 
+sonnet (5.22.0-0ubuntu1) yakkety; urgency=medium
+
+  [ Scarlett Clark ]
+  * New upstream release. 
+  * Debian merge: No remaining changes. 
+
+  [ Philip Muškovac ]
+  * Update the Vcs URLs now that the repositories are hosted on
+    Launchpad
+
+  [ Clive Johnston ]
+  * Adding usr/bin/parsetrigrams to install file
+  * Fixing missing-dependency-on-libc
+  * New upstream release
+
+ -- Clive Johnston <clivejo@kubuntu.org>  Tue, 17 May 2016 17:03:33 -0700
+
 sonnet (5.22.0-0neon) xenial; urgency=medium
 
   * New release
@@ -386,6 +611,17 @@ sonnet (5.18.0-1) experimental; urgency=
 
  -- Maximiliano Curia <maxy@debian.org>  Wed, 27 Jan 2016 13:33:11 +0100
 
+sonnet (5.18.0-0ubuntu1) xenial; urgency=medium
+
+  [ Scarlett Clark ]
+  * Debian Merge: No remaining changes. 
+  * New upstream release Xenial
+
+  [ Philip Muškovac ]
+  * New upstream release
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Wed, 06 Jan 2016 15:13:12 +0100
+
 sonnet (5.16.0-1) unstable; urgency=medium
 
   * New upstream release (5.16.0).
diff -pruN 5.69.0-1/debian/compat 5.70.0-0ubuntu1/debian/compat
--- 5.69.0-1/debian/compat	1970-01-01 00:00:00.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/compat	2020-05-09 11:35:42.000000000 +0000
@@ -0,0 +1 @@
+11
diff -pruN 5.69.0-1/debian/control 5.70.0-0ubuntu1/debian/control
--- 5.69.0-1/debian/control	2020-04-23 19:34:58.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/control	2020-05-09 11:35:42.000000000 +0000
@@ -4,10 +4,10 @@ Priority: optional
 Maintainer: Debian/Kubuntu Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
 Uploaders: Maximiliano Curia <maxy@debian.org>
 Build-Depends: aspell,
-               cmake (>= 3.5~),
-               debhelper-compat (= 12),
+               cmake (>= 3.0~),
+               debhelper (>= 11~),
                doxygen,
-               extra-cmake-modules (>= 5.69.0~),
+               extra-cmake-modules (>= 5.70.0~),
                graphviz,
                hspell,
                libaspell-dev,
@@ -16,26 +16,26 @@ Build-Depends: aspell,
                libvoikko-dev,
                pkg-config,
                pkg-kde-tools (>= 0.15.15ubuntu1~),
-               qtbase5-dev (>= 5.12.0~),
-               qttools5-dev (>= 5.4),
-               qttools5-dev-tools (>= 5.4),
+               qtbase5-dev (>= 5.8.0~),
+               qttools5-dev (>= 5.6.1~),
+               qttools5-dev-tools (>= 5.6.1~),
                xauth,
                xvfb,
-               zlib1g-dev
-Standards-Version: 4.5.0
+               zlib1g-dev,
+Standards-Version: 4.1.4
 Homepage: http://projects.kde.org/sonnet
-Vcs-Browser: https://salsa.debian.org/qt-kde-team/kde/sonnet
-Vcs-Git: https://salsa.debian.org/qt-kde-team/kde/sonnet.git
-Rules-Requires-Root: no
+Vcs-Browser: https://code.launchpad.net/~kubuntu-packagers/kubuntu-packaging/+git/sonnet
+Vcs-Git: https://git.launchpad.net/~kubuntu-packagers/kubuntu-packaging/+git/sonnet
 
 Package: libkf5sonnet-dev
-Section: libdevel
 Architecture: any
+Section: libdevel
 Depends: libkf5sonnet-dev-bin (= ${binary:Version}),
          libkf5sonnetcore5 (= ${binary:Version}),
          libkf5sonnetui5 (= ${binary:Version}),
-         qtbase5-dev (>= 5.12.0~),
-         ${misc:Depends}
+         qtbase5-dev (>= 5.8.0~),
+         ${misc:Depends},
+         ${shlibs:Depends},
 Recommends: libkf5sonnet-doc (= ${source:Version})
 Description: spell checking library for Qt, devel files
  Sonnet is a Qt based library that offers easy access to spell
@@ -44,12 +44,11 @@ Description: spell checking library for
  .
  This package contains development files for building software that uses
  libraries from the Sonnet framework.
-Breaks: libkf5khtml-dev (<< 5.54), libkf5textwidgets-dev (<< 5.54)
 
 Package: libkf5sonnet-dev-bin
-Section: libdevel
 Architecture: any
 Multi-Arch: foreign
+Section: libdevel
 Depends: ${misc:Depends}, ${shlibs:Depends}
 Breaks: libkf5sonnet-dev (<< 5.27.0)
 Replaces: libkf5sonnet-dev (<< 5.27.0)
@@ -63,6 +62,7 @@ Description: spell checking library for
 Package: libkf5sonnet-doc
 Architecture: all
 Multi-Arch: foreign
+Section: doc
 Depends: ${misc:Depends}
 Description: spell checking library for Qt (documentation)
  Sonnet is a Qt based library that offers easy access to spell
@@ -70,7 +70,6 @@ Description: spell checking library for
  Frameworks 5.
  .
  This package contains the qch documentation files.
-Section: doc
 
 Package: libkf5sonnet5-data
 Architecture: all
@@ -86,52 +85,46 @@ Description: spell checking library for
 Package: libkf5sonnetcore5
 Architecture: any
 Multi-Arch: same
+Section: libs
 Depends: libkf5sonnet5-data (= ${source:Version}),
          ${misc:Depends},
-         ${shlibs:Depends}
+         ${shlibs:Depends},
 Recommends: sonnet-plugins (= ${binary:Version})
+Breaks: kdesignerplugin (<< 5.42)
 Description: spell checking library for Qt, core lib
  Sonnet is a Qt based library that offers easy access to spell
  checking using various plugin based backends.  It is part of KDE
  Frameworks 5.
-Breaks: kdesignerplugin (<< 5.42),
-        libkf5khtml5 (<< 5.54),
-        libkf5texteditor5 (<< 5.54),
-        libkf5textwidgets5 (<< 5.54)
 
 Package: libkf5sonnetui5
 Architecture: any
 Multi-Arch: same
 Depends: ${misc:Depends}, ${shlibs:Depends}
 Recommends: sonnet-plugins (= ${binary:Version})
-Description: spell checking library for Qt, ui lib
- Sonnet is a Qt based library that offers easy access to spell
- checking using various plugin based backends.  It is part of KDE
- Frameworks 5.
- .
- This package provides Qt based GUI elements that can be used
- by projects to construct spell checking user interfaces.
-Breaks: kdesignerplugin (<< 5.54),
-        kio (<< 5.42),
+Breaks: kio (<< 5.42),
         kross (<< 5.42),
         ktexteditor-katepart (<< 5.42),
         libkf5kdelibs4support5 (<< 5.42),
         libkf5kdelibs4support5-bin (<< 5.42),
         libkf5khtml-bin (<< 5.42),
-        libkf5khtml5 (<< 5.54),
         libkf5krossui5 (<< 5.42),
         libkf5mediaplayer5 (<< 5.42),
         libkf5newstuff5 (<< 5.42),
         libkf5parts-plugins (<< 5.42),
         libkf5parts5 (<< 5.42),
-        libkf5texteditor5 (<< 5.54),
-        libkf5textwidgets5 (<< 5.54),
         libkf5webkit5 (<< 5.42),
-        libkf5xmlgui5 (<< 5.42)
+        libkf5xmlgui5 (<< 5.42),
+Description: spell checking library for Qt, ui lib
+ Sonnet is a Qt based library that offers easy access to spell
+ checking using various plugin based backends.  It is part of KDE
+ Frameworks 5.
+ .
+ This package provides Qt based GUI elements that can be used
+ by projects to construct spell checking user interfaces.
 
 Package: sonnet-plugins
-Section: kde
 Architecture: any
+Section: kde
 Depends: ${misc:Depends}, ${shlibs:Depends}
 Suggests: hspell
 Description: spell checking library for Qt, plugins
diff -pruN 5.69.0-1/debian/libkf5sonnet5-data.maintscript 5.70.0-0ubuntu1/debian/libkf5sonnet5-data.maintscript
--- 5.69.0-1/debian/libkf5sonnet5-data.maintscript	2020-04-13 19:38:48.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/libkf5sonnet5-data.maintscript	2020-05-09 11:35:42.000000000 +0000
@@ -1 +1 @@
-rm_conffile /etc/xdg/sonnet.categories 5.61.0-1~~
+rm_conffile /etc/xdg/sonnet.categories
diff -pruN 5.69.0-1/debian/libkf5sonnetcore5.symbols 5.70.0-0ubuntu1/debian/libkf5sonnetcore5.symbols
--- 5.69.0-1/debian/libkf5sonnetcore5.symbols	2020-04-14 23:16:21.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/libkf5sonnetcore5.symbols	2020-05-09 11:35:42.000000000 +0000
@@ -1,6 +1,5 @@
-# SymbolsHelper-Confirmed: 5.69.0 amd64
+# SymbolsHelper-Confirmed: 5.69.0 amd64 arm64 armhf ppc64el s390x
 libKF5SonnetCore.so.5 libkf5sonnetcore5 #MINVER#
-* Build-Depends-Package: libkf5sonnet-dev
  _ZN6Sonnet10TextBreaks10wordBreaksERK7QString@Base 4.96.0
  _ZN6Sonnet10TextBreaks14sentenceBreaksERK7QString@Base 4.96.0
  _ZN6Sonnet10TextBreaks7setTextERK7QString@Base 4.96.0
@@ -194,7 +193,7 @@ libKF5SonnetCore.so.5 libkf5sonnetcore5
  _ZNK6Sonnet6Loader13createSpellerERK7QStringS3_@Base 4.96.0
  _ZNK6Sonnet6Loader13languageNamesEv@Base 4.96.0
  _ZNK6Sonnet6Loader19languageNameForCodeERK7QString@Base 4.96.0
- _ZNK6Sonnet6Loader23loadingDictionaryFailedERK7QString@Base 5.61.0
+ _ZNK6Sonnet6Loader23loadingDictionaryFailedERK7QString@Base 5.56.0
  _ZNK6Sonnet6Loader7clientsEv@Base 4.96.0
  _ZNK6Sonnet6Loader8settingsEv@Base 4.96.0
  _ZNK6Sonnet6Loader9languagesEv@Base 4.96.0
diff -pruN 5.69.0-1/debian/libkf5sonnet-dev.acc.in 5.70.0-0ubuntu1/debian/libkf5sonnet-dev.acc.in
--- 5.69.0-1/debian/libkf5sonnet-dev.acc.in	2020-04-13 19:38:48.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/libkf5sonnet-dev.acc.in	2020-05-09 11:35:42.000000000 +0000
@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
+<?xml version='1.0' encoding='utf-8'?>
 <descriptor>
 
 <version>
@@ -17,6 +17,7 @@
 
 <gcc_options>
     -fPIC
+    -fno-keep-inline-functions
     -std=c++11
 </gcc_options>
 
diff -pruN 5.69.0-1/debian/libkf5sonnet-dev.install 5.70.0-0ubuntu1/debian/libkf5sonnet-dev.install
--- 5.69.0-1/debian/libkf5sonnet-dev.install	2020-04-13 19:38:48.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/libkf5sonnet-dev.install	2020-05-09 11:35:42.000000000 +0000
@@ -6,3 +6,4 @@ usr/lib/*/libKF5SonnetCore.so
 usr/lib/*/libKF5SonnetUi.so
 usr/lib/*/qt5/mkspecs/modules/qt_SonnetCore.pri
 usr/lib/*/qt5/mkspecs/modules/qt_SonnetUi.pri
+usr/lib/*/qt5/plugins/designer/sonnetui5widgets.so
diff -pruN 5.69.0-1/debian/libkf5sonnetui5.symbols 5.70.0-0ubuntu1/debian/libkf5sonnetui5.symbols
--- 5.69.0-1/debian/libkf5sonnetui5.symbols	2020-04-14 23:07:23.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/libkf5sonnetui5.symbols	2020-05-09 11:35:42.000000000 +0000
@@ -1,6 +1,5 @@
-# SymbolsHelper-Confirmed: 5.69.0 amd64
+# SymbolsHelper-Confirmed: 5.69.0 amd64 arm64 armhf ppc64el s390x
 libKF5SonnetUi.so.5 libkf5sonnetui5 #MINVER#
-* Build-Depends-Package: libkf5sonnet-dev
  _ZN6Sonnet10ConfigView11qt_metacallEN11QMetaObject4CallEiPPv@Base 5.69.0
  _ZN6Sonnet10ConfigView11qt_metacastEPKc@Base 5.69.0
  _ZN6Sonnet10ConfigView11setLanguageERK7QString@Base 5.69.0
@@ -80,8 +79,8 @@ libKF5SonnetUi.so.5 libkf5sonnetui5 #MIN
  _ZN6Sonnet18DictionaryComboBox11reloadComboEv@Base 4.96.0
  _ZN6Sonnet18DictionaryComboBox16staticMetaObjectE@Base 4.96.0
  _ZN6Sonnet18DictionaryComboBox17dictionaryChangedERK7QString@Base 4.96.0
- _ZN6Sonnet18DictionaryComboBox19assignByDictionnaryERK7QString@Base 5.41.0
- _ZN6Sonnet18DictionaryComboBox21assignDictionnaryNameERK7QString@Base 5.41.0
+ _ZN6Sonnet18DictionaryComboBox19assignByDictionnaryERK7QString@Base 5.40.0
+ _ZN6Sonnet18DictionaryComboBox21assignDictionnaryNameERK7QString@Base 5.40.0
  _ZN6Sonnet18DictionaryComboBox21dictionaryNameChangedERK7QString@Base 4.96.0
  _ZN6Sonnet18DictionaryComboBox22setCurrentByDictionaryERK7QString@Base 4.96.0
  _ZN6Sonnet18DictionaryComboBox26setCurrentByDictionaryNameERK7QString@Base 4.96.0
@@ -114,7 +113,7 @@ libKF5SonnetUi.so.5 libkf5sonnetui5 #MIN
  _ZN6Sonnet6Dialog12updateDialogERK7QString@Base 4.96.0
  _ZN6Sonnet6Dialog13setGuiEnabledEb@Base 4.96.0
  _ZN6Sonnet6Dialog14slotReplaceAllEv@Base 4.96.0
- _ZN6Sonnet6Dialog14spellCheckDoneERK7QString@Base 5.69.0
+ _ZN6Sonnet6Dialog14spellCheckDoneERK7QString@Base 5.65.0
  _ZN6Sonnet6Dialog15fillSuggestionsERK11QStringList@Base 4.96.0
  _ZN6Sonnet6Dialog15initConnectionsEv@Base 4.96.0
  _ZN6Sonnet6Dialog15languageChangedERK7QString@Base 4.96.0
diff -pruN 5.69.0-1/debian/rules 5.70.0-0ubuntu1/debian/rules
--- 5.69.0-1/debian/rules	2020-04-29 01:20:40.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/rules	2020-05-09 11:35:42.000000000 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/make -f
 
-export DEB_BUILD_MAINT_OPTIONS = hardening=+all
+export DEB_LDFLAGS_MAINT_APPEND := -Wl,--as-needed
 
 %:
 	dh $@ --with kf5,pkgkde_symbolshelper --buildsystem kf5 --without build_stamp
@@ -12,3 +12,6 @@ override_dh_auto_test:
 	export XDG_RUNTIME_DIR="$$(mktemp -d)"; \
 	 xvfb-run -a dh_auto_test; \
 	 rm -rf "$$XDG_RUNTIME_DIR"
+
+override_dh_strip:
+	dh_strip --dbgsym-migration='libkf5sonnet5-dbg (<= 5.19.0-1~~)'
diff -pruN 5.69.0-1/debian/salsa/extra_repository.list 5.70.0-0ubuntu1/debian/salsa/extra_repository.list
--- 5.69.0-1/debian/salsa/extra_repository.list	2020-04-13 21:16:46.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/salsa/extra_repository.list	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-deb https://qt-kde-team.debian.net/debian qt-kde-snapshots main
diff -pruN 5.69.0-1/debian/salsa/qt-kde-team.debian.net.asc 5.70.0-0ubuntu1/debian/salsa/qt-kde-team.debian.net.asc
--- 5.69.0-1/debian/salsa/qt-kde-team.debian.net.asc	2020-04-13 21:16:51.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/salsa/qt-kde-team.debian.net.asc	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
------BEGIN PGP PUBLIC KEY BLOCK-----
-
-mQINBFbRhD8BEADR1NNpDI/ekbEMKy0rn8wYWMFgkdg8T7U7iok+QbNd6pad7ZmY
-vMZ9YydyKFDXzrXdx06SFDUMdFnYHhedReROJF3C6/IWBQHHKsad1cxu6HtHwBER
-P7CMqyjwbQaNf7VR40iSPLiSH4AhpW4L9G0POCrl3oMVKRreMhk86aST6H5YLafb
-CTwoELE5GU50pNMena98MUdjCrDNPRdUu1+GFxjjGB5T2ESeQ1zsa1OhMxHw8dgt
-pk35WTyD5ETGYs6JVpN1GYvGruCm6dKjMMgIiH0OO7oNUtkqiUE/jAzb0UEX1VqS
-d74QrFpqfRpDy+gatglYt3aK1k6HX2aGR3NJshtjejjVhDpOTn8oQrslD+Rtn7nN
-bdzf5agYFzyfWBA/466VXWpRp0n+2QfDYnpabuzKN+CYaWsIdpNgVgr3PshpTzKV
-vN3wle0V5kEeA1wO5lNRcc+NG98SvL+gNIrH0BZzNOVKAGuZ83pm2cr636IJSBTo
-wP40+RWCy5skB67s6MlXa3tq4Q/EVoL9VdgyffOQHgVb6d2jMiXXEjPYqPVnsWkp
-w7+PgqaH32wLKwyUbYRz21WVzkwbFr7LvDgaj0PiI9r5c/qN4cKmi4+1zgJuAFOh
-wjKbRIzFOApYmcIWXA8suVhUHgzKye1Cix4mD0eoKIGA2nM+wEvLy0DcaQARAQAB
-tDxMWFF0IFBhY2thZ2luZyBUZWFtIDxwa2ctbHhxdC1kZXZlbEBsaXN0cy5hbGlv
-dGguZGViaWFuLm9yZz6JAjcEEwEKACEFAlbRhD8CGwMFCwkIBwMFFQoJCAsFFgID
-AQACHgECF4AACgkQOgXVl5oByVEhUxAAp3TQOStOjwRN26/I4YFeMttDQ3AlWuSB
-PycTZbkHoZLNkvIJJuzoXkGXiGZLA7UVuEPTEztB3Bo3IgB+FiDkXWUtG5qj42KV
-vqGYq8IjIO8gxRQH+ZK0aiPIZrcCE2z7jFi5ocGVDveS9PbXs7FxVnuP+nBvpuI9
-e43rJM5VgQZbVQbqSmyeaM5KFd+izTfkm0qDVRz6X0l+q1lb2fRjalYXtrueeQro
-0E7r1QrYgCxvWT8L71E8eRAdrDbmtCTUebIE/Dle6TDm/tagS9I05COEdOFi2SPa
-I4esRzU1tuQxtCVb8E+1rSi1wmNRQSDr2GumIGAJC8ME5StuntwLAJXbzWu/NjJT
-uNz2noyfk4ZRNVRuJAZjFivJQqAC1ycRJpLPZuHFJy8Z+8ugKD3sE6MJJfM/tZi1
-hD1nZzgV35uPo2kgVe96zZQlDAZJVlNIF5GOFNOgSN/s+Bq8/zmBJGrkz6/kwRp7
-dJJG1BSMGoyi1vh3Iy9H+Eq1TYd2C1u3GbV2wE7UR2d9Obt+NmCwTpG0nimsW0DD
-KNNuzkgBjBQUpt0b99gJULI6aYxWFIvTD77fsmjaKgnlx4shS0y4i+L5sOWqdTXX
-ICu+Xnq0ROzmf1+aOGeR500RR7OjU+PmShDklmdE5Ss3Hzqi36tTipGpjKDaDoKA
-lM6xZCxUi+25Ag0EVtGEPwEQALR3uffc7bq+xGUVUtCiEbeOYvEDYzoZPvt/Yu57
-BQ56Ar/SkrKthAt7C+IMOJ2NJDHRWtkcYOqQqb4anAlf9a7NSkIwtZh4KeXfA6VZ
-3T3JubIrMcO0YFKi11wga2BNkDPv+z9MdYPq9ocoP7pyIWSz70TE/Yo1aaA18l6g
-Rx1Wdg/+vjrNjcz8BVEM1szaZTGSb8W2lPqESiG/lTUC90rGKh+7fbEOJPvf1CG9
-wzGgH5NhcU4evu14obvQTwmXo6XPjmx7YtvcfQynNBECdJOyZg2O6qR4wwMKYzSU
-+U0KnntCxSFGt4cspnMvnC13DhRmfRJoZxCaCA2GE6ThLu6aqAqcXvaUQUZRP9o/
-HIQm4rEPaZSdJq4pgPv8QKOXWhvk88uh0xW5j2tYyrS8klok42tXIKmGhYej13rJ
-e2CJ57bZTGz12ferGCLUUMTH3oAUxdzykrao/gDk+kKxxYpCe6MAbtamVbsBbiar
-rp11y4WhLmeb69SXrE2uNJSf71f7GvjjiZQoCvRJL/1OFtpUCj/c8Dz+8gnMsPwU
-lXJa7tbsxLrOhkNf/clBt4Nf/v60o7Ig9glgyuNXc2cq8VtP+vU3Pde1GNJp4qsP
-JgmlU97n1eIdubg2o7HBsSBJ860+Fn2CfnO1umQoMP0uzF4M5fyfTWXy0A/DgFEH
-7o03ABEBAAGJAh8EGAEKAAkFAlbRhD8CGwwACgkQOgXVl5oByVHfeA/9HCaVGqpv
-RaZa5ciomYsg9vsZoMB6WhM1kyG11utwgV+Hl9XhktAFFo6B9BnyzhxYGn8Tcefi
-Et3lKi/vt6vvk9BU5sKmE9Pt+T9tnjK8MKcOHco0bmnCByE6HZxtVkcSlYgnyf4s
-II9kQoSADwwodQn4f5JSb9NIxHxBD+Aga3d4yYBDOLrBzW2BN6xilqTGZpcMioht
-8VIOvs/YUOpLhZuARtPszCUjGB/WGspQlrIldSRIpvshSUd79SrcYM5OyzeuF7aP
-h1xt+3l5kxDE1oKYgW9rKycp6liillOQyZlIJmeU2D30IqVQshYDfYvy/3cL9TO6
-CcYGkBaFFf8fKGEEBWG35M0+PXaiivQ2efBfekt1i3MaFn25t2Lgjt31wKjZqRfZ
-xRFodkRx/qSxZcaJU8NYSxVC2OEwlEIN0v3/eWZMOzYwFvCcg/a3M7ARlQOwt1YZ
-Lsj83SJ263KjdGpgDE0Rk6B416dT/vClRmGg5jyX05keymzzfl//z93rerwPqbV/
-ygi4vRVswBSrACwRKXEzaUEeutGX8L49XFNi/p5gYL8RCTGOM4PxD5AmTC7+VnnO
-T1155UsunpBrlFUTKhxJGUux11TgojiGJY3ID7fP8EqyZWp6z3CXqXTxv8CP8Ye1
-bMTcHe5rk6snXqz1neEmP2K7qdNwwakRdAA=
-=o8PI
------END PGP PUBLIC KEY BLOCK-----
diff -pruN 5.69.0-1/debian/salsa-ci.yml 5.70.0-0ubuntu1/debian/salsa-ci.yml
--- 5.69.0-1/debian/salsa-ci.yml	2020-04-13 21:16:30.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/salsa-ci.yml	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-include:
-  - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/salsa-ci.yml
-  - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/pipeline-jobs.yml
-variables:
-  SALSA_CI_DISABLE_MISSING_BREAKS: 'no'
-  SALSA_CI_DISABLE_RC_BUGS: 'no'
-  SALSA_CI_REPROTEST_ARGS: '--variations=-build-path'
-  EXTRA_REPOSITORY: 'debian/salsa/extra_repository.list'
-  EXTRA_REPOSITORY_KEY: 'debian/salsa/qt-kde-team.debian.net.asc'
diff -pruN 5.69.0-1/debian/tests/control 5.70.0-0ubuntu1/debian/tests/control
--- 5.69.0-1/debian/tests/control	2020-04-13 19:38:48.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/tests/control	2020-05-09 11:35:42.000000000 +0000
@@ -1,3 +1,7 @@
+# Tests: testsuite
+# Depends: @, @builddeps@, build-essential
+# Restrictions: build-needed
+
 Tests: acc
-Depends: dh-acc, exuberant-ctags, @
+Depends: @, dh-acc, exuberant-ctags
 Restrictions: allow-stderr
diff -pruN 5.69.0-1/debian/watch 5.70.0-0ubuntu1/debian/watch
--- 5.69.0-1/debian/watch	2020-04-15 01:25:54.000000000 +0000
+++ 5.70.0-0ubuntu1/debian/watch	2020-05-09 11:35:42.000000000 +0000
@@ -1,3 +1,3 @@
 version=4
 
-opts=pgpsigurlmangle=s/$/.sig/ https://download.kde.org/stable/frameworks/([\d\.]*)/sonnet-(.*)\.tar\.xz
+opts=pgpsigurlmangle=s/$/.sig/ http://download.kde.org/stable/frameworks/([\d\.]*)/sonnet-(.*)\.tar\.xz
diff -pruN 5.69.0-1/po/en_GB/sonnet5_qt.po 5.70.0-0ubuntu1/po/en_GB/sonnet5_qt.po
--- 5.69.0-1/po/en_GB/sonnet5_qt.po	2020-04-04 23:07:54.000000000 +0000
+++ 5.70.0-0ubuntu1/po/en_GB/sonnet5_qt.po	2020-05-02 22:25:43.000000000 +0000
@@ -10,7 +10,7 @@ msgstr ""
 "POT-Creation-Date: 2014-03-23 01:50+0000\n"
 "PO-Revision-Date: 2019-03-24 19:22+0000\n"
 "Last-Translator: Steve Allewell <steve.allewell@gmail.com>\n"
-"Language-Team: British English <kde-i18n-doc@kde.org>\n"
+"Language-Team: British English <kde-l10n-en_gb@kde.org>\n"
 "Language: en_GB\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
diff -pruN 5.69.0-1/po/ko/sonnet5_qt.po 5.70.0-0ubuntu1/po/ko/sonnet5_qt.po
--- 5.69.0-1/po/ko/sonnet5_qt.po	2020-04-04 23:07:54.000000000 +0000
+++ 5.70.0-0ubuntu1/po/ko/sonnet5_qt.po	2020-05-02 22:25:43.000000000 +0000
@@ -1,14 +1,14 @@
 # Korean messages for kdelibs.
 # Copyright (C) Free Software Foundation, Inc.
 # Cho Sung Jae <cho.sungjae@gmail.com>, 2007.
-# Shinjo Park <kde@peremen.name>, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2019.
+# Shinjo Park <kde@peremen.name>, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2019, 2020.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n"
 "POT-Creation-Date: 2014-03-23 01:50+0000\n"
-"PO-Revision-Date: 2019-04-12 00:57+0100\n"
+"PO-Revision-Date: 2020-04-05 01:58+0200\n"
 "Last-Translator: Shinjo Park <kde@peremen.name>\n"
 "Language-Team: Korean <kde-kr@kde.org>\n"
 "Language: ko\n"
@@ -16,7 +16,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Generator: Lokalize 2.0\n"
+"X-Generator: Lokalize 19.04.3\n"
 "X-Qt-Contexts: true\n"
 
 #: core/loader.cpp:176
@@ -305,7 +305,7 @@ msgstr "언어(&L):"
 #: ui/sonnetui.ui:85
 msgctxt "SonnetUi|"
 msgid "Text excerpt showing the unknown word in its context."
-msgstr "이 문맥에서 알 수 없는 단어를 포함하는 문단의 일부분입니다."
+msgstr "이 문맥에서 알 수 없는 단어가 들어 있는 문단의 일부분입니다."
 
 #: ui/sonnetui.ui:88
 msgctxt "SonnetUi|"
@@ -318,10 +318,10 @@ msgid ""
 "</qt>"
 msgstr ""
 "<qt>\n"
-"<p>여기에서 알 수 없는 단어를 포함하는 문단의 일부분을 볼 수 있습니다. 만약 "
+"<p>여기에서 알 수 없는 단어가 들어 있는 문단의 일부분을 볼 수 있습니다. 만약 "
 "이 정보만 가지고 알 수 없는 단어의 적합한 대체 단어를 선택할 수 없다면, 검사"
-"하고 있는 문서를 누른 다음 문단의 더 많은 부분을 읽으신 후, 이곳으로 되돌아"
-"와 검사를 계속할 수 있습니다.</p>\n"
+"하고 있는 문서를 누른 다음 문단의 더 많은 부분을 읽은 후, 여기로 되돌아와 검"
+"사를 계속할 수 있습니다.</p>\n"
 "</qt>"
 
 #: ui/sonnetui.ui:96
